@@ -28,6 +28,7 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_nova_config('vnc/novncproxy_base_url') }
       it { is_expected.to contain_nova_config('key_manager/backend').with_value('nova.keymgr.conf_key_mgr.ConfKeyManager') }
       it { is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>') }
@@ -35,7 +36,9 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
@@ -74,12 +77,14 @@ describe 'nova::compute' do
           :config_drive_format                => 'vfat',
           :resize_confirm_window              => '3',
           :vcpu_pin_set                       => ['4-12','^8','15'],
+          :cpu_shared_set                     => ['4-12','^8','15'],
           :resume_guests_state_on_host_boot   => true,
           :keymgr_backend                     => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :barbican_endpoint                  => 'http://localhost',
           :barbican_api_version               => 'v1',
           :barbican_auth_endpoint             => 'http://127.0.0.1:5000/v3',
           :max_concurrent_live_migrations     => '4',
+          :sync_power_state_pool_size         => '10',
           :verify_glance_signatures           => true,
           :consecutive_build_service_disable_threshold => '9',
         }
@@ -121,6 +126,10 @@ describe 'nova::compute' do
         )
       end
 
+      it 'should have spice disabled' do
+        is_expected.to contain_nova_config('spice/enabled').with_value(false)
+      end
+
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('120') }
 
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with(:value => false) }
@@ -129,8 +138,12 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '4-12,^8,15') }
 
+      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '4-12,^8,15') }
+
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('4') }
 
+      it { is_expected.to contain_nova_config('DEFAULT/sync_power_state_pool_size').with_value('10') }
+
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('9') }
 
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
@@ -144,6 +157,32 @@ describe 'nova::compute' do
       end
     end
 
+    context 'with reserved_huge_pages string' do
+      let :params do
+        {
+            :reserved_huge_pages => "foo"
+        }
+      end
+      it 'configures nova reserved_huge_pages entries' do
+        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
+          'value' => 'foo'
+        )
+      end
+    end
+
+    context 'with reserved_huge_pages array' do
+      let :params do
+        {
+            :reserved_huge_pages => ["foo", "bar"]
+        }
+      end
+      it 'configures nova reserved_huge_pages entries' do
+        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
+          'value' => ['foo','bar']
+        )
+      end
+    end
+
     context 'with barbican deprecated parameters' do
       let :params do
         {
@@ -166,6 +205,16 @@ describe 'nova::compute' do
       end
     end
 
+    context 'when cpu_shared_set is empty' do
+      let :params do
+        { :cpu_shared_set    => ""}
+      end
+
+      it 'clears cpu_shared_set configuration' do
+        is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with neutron_enabled set to false' do
       let :params do
         { :neutron_enabled => false }
@@ -181,6 +230,28 @@ describe 'nova::compute' do
 
     end
 
+    context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are empty' do
+      let :params do
+        { :neutron_physnets_numa_nodes_mapping => {},
+          :neutron_tunnel_numa_nodes           => [], }
+      end
+
+      it { is_expected.to contain_nova_config('neutron/physnets').with(:ensure => 'absent') }
+      it { is_expected.to contain_nova_config('neutron_tunnel/numa_nodes').with(:ensure => 'absent') }
+    end
+
+    context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are set to valid values' do
+      let :params do
+        { :neutron_physnets_numa_nodes_mapping => { 'foo' => [0, 1], 'bar' => [0] },
+          :neutron_tunnel_numa_nodes           => 1, }
+      end
+
+      it { is_expected.to contain_nova_config('neutron/physnets').with(:value => 'foo,bar') }
+      it { is_expected.to contain_nova_config('neutron_physnet_foo/numa_nodes').with(:value => '0,1') }
+      it { is_expected.to contain_nova_config('neutron_physnet_bar/numa_nodes').with(:value => '0') }
+      it { is_expected.to contain_nova_config('neutron_tunnel/numa_nodes').with(:value => '1') }
+    end
+
     context 'with install_bridge_utils set to false' do
       let :params do
         { :install_bridge_utils => false }
@@ -194,9 +265,10 @@ describe 'nova::compute' do
 
     end
 
-    context 'with vnc_enabled set to false' do
+    context 'with vnc_enabled set to false and spice_enabled set to true' do
       let :params do
-        { :vnc_enabled => false }
+        { :vnc_enabled => false,
+          :spice_enabled => true, }
       end
 
       it 'disables vnc in nova.conf' do
@@ -205,6 +277,19 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('vnc/keymap').with_ensure('absent')
         is_expected.to_not contain_nova_config('vnc/novncproxy_base_url')
       end
+
+      it 'enables spice' do
+        is_expected.to contain_nova_config('spice/enabled').with_value(true)
+      end
+    end
+
+    context 'with vnc_enabled and spice_enabled set to true' do
+      let :params do
+        { :vnc_enabled   => true,
+          :spice_enabled => true, }
+      end
+
+      it { is_expected.to raise_error Puppet::Error, /vnc_enabled and spice_enabled is mutually exclusive/ }
     end
 
     context 'with force_config_drive parameter set to true' do
