@@ -42,11 +42,7 @@ describe 'nova' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       end
@@ -58,6 +54,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
         is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
@@ -66,6 +63,9 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -77,16 +77,11 @@ describe 'nova' do
     context 'with overridden parameters' do
 
       let :params do
-        { :debug                                   => true,
-          :log_dir                                 => '/var/log/nova2',
+        {
           :image_service                           => 'nova.image.local.LocalImageService',
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
-          :rabbit_host                             => 'rabbit',
-          :rabbit_userid                           => 'rabbit_user',
-          :rabbit_port                             => '5673',
-          :rabbit_password                         => 'password',
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
           :lock_path                               => '/var/locky/path',
@@ -102,6 +97,7 @@ describe 'nova' do
           :notify_on_api_faults                    => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
+          :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
           :use_ipv6                                => true,
           :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
@@ -116,6 +112,9 @@ describe 'nova' do
           :block_device_allocate_retries           => '60',
           :block_device_allocate_retries_interval  => '3',
           :my_ip                                   => '192.0.2.1',
+          :ssl_only                                => true,
+          :cert                                    => '/etc/ssl/private/snakeoil.pem',
+          :key                                     => '/etc/ssl/certs/snakeoil.pem',
         }
       end
 
@@ -144,11 +143,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
       end
@@ -184,8 +178,12 @@ describe 'nova' do
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
+        is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
+        is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
       end
 
       context 'with multiple notification_driver' do
@@ -233,45 +231,6 @@ describe 'nova' do
       end
     end
 
-    context 'with rabbit_hosts parameter' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
-    context 'with rabbit_hosts parameter (one server)' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
     context 'with kombu_reconnect_delay set to 5.0' do
       let :params do
         { :kombu_reconnect_delay => '5.0' }
@@ -292,10 +251,9 @@ describe 'nova' do
       end
     end
 
-    context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
+    context 'with rabbit_ha_queues set to false' do
       let :params do
-        { :rabbit_ha_queues => 'false',
-          :rabbit_hosts => ['rabbit:5673'] }
+        { :rabbit_ha_queues => false }
       end
 
       it 'configures rabbit' do
@@ -305,26 +263,21 @@ describe 'nova' do
 
     context 'with amqp_durable_queues parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => true }
+        { :amqp_durable_queues => true }
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
         is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
         )
       end
     end
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true,
+        { :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
@@ -342,12 +295,11 @@ describe 'nova' do
 
     context 'with rabbit ssl enabled without kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true, }
+        { :rabbit_use_ssl => true, }
       end
 
       it { is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-        :rabbit_use_ssl     => true,
+        :rabbit_use_ssl => true,
       )}
     end
 
